@@ -72,9 +72,9 @@ class cell_cache(wrapper):
 
     
     """
-    def __init__(self, function = None, db = 'cache', table = None, url = None, server = None, pk = None, cell = periodic_cell, writer = None, cell_kwargs = None, external = None):
+    def __init__(self, function = None, db = 'cache', schema = None, table = None, url = None, server = None, pk = None, cell = periodic_cell, writer = None, cell_kwargs = None, external = None):
         cell_kwargs  = cell_kwargs or {}
-        db_kwargs = dict(pk = pk, db = db, table = table, url = url, server = server, writer = writer)
+        db_kwargs = dict(pk = pk, db = db, table = table, schema = schema, url = url, server = server, writer = writer)
         if isinstance(db, partial):
             db_kwargs.update(db.keywords)
         super(cell_cache, self).__init__(function = function, cell = cell, cell_kwargs = cell_kwargs, external = external, **db_kwargs)
@@ -104,11 +104,11 @@ class cell_cache(wrapper):
     
     @property
     def _db(self):
-        mode = _get_db(self.url, self.server)
+        mode = _get_db(self.url, self.server, self.schema)
         if mode == 'mongo':    
             return partial(DBS[mode], table = self._table, db = self.db, pk = self._pk, url = self.url or self.server, writer = self.writer)
         elif mode == 'sql':
-            return partial(DBS[mode], table = self._table, db = self.db, pk = self._pk, server = self.server or self.url, writer = self.writer)
+            return partial(DBS[mode], table = self._table, schema = self.schema, db = self.db, pk = self._pk, server = self.server or self.url, writer = self.writer)
         else:
             raise ValueError('only sql or mongo are supported')            
     
